EXPORTS
	??1CStartupProperties@@UAE@XZ @ 1 NONAME ; CStartupProperties::~CStartupProperties(void)
	?Args@CStartupProperties@@QBE?AVTPtrC16@@XZ @ 2 NONAME ; class TPtrC16 CStartupProperties::Args(void) const
	?ExternalizeL@CStartupProperties@@QBEXAAVCBufBase@@@Z @ 3 NONAME ; void CStartupProperties::ExternalizeL(class CBufBase &) const
	?FileName@CStartupProperties@@QBE?AVTPtrC16@@XZ @ 4 NONAME ; class TPtrC16 CStartupProperties::FileName(void) const
	?InternalizeL@CStartupProperties@@QAEXABVTPtrC8@@@Z @ 5 NONAME ; void CStartupProperties::InternalizeL(class TPtrC8 const &)
	?Monitored@CStartupProperties@@QBEHXZ @ 6 NONAME ; int CStartupProperties::Monitored(void) const
	?NewL@CStartupProperties@@SAPAV1@AAVTResourceReader@@@Z @ 7 NONAME ; class CStartupProperties * CStartupProperties::NewL(class TResourceReader &)
	?NewL@CStartupProperties@@SAPAV1@ABVTDesC16@@0@Z @ 8 NONAME ; class CStartupProperties * CStartupProperties::NewL(class TDesC16 const &, class TDesC16 const &)
	?NewL@CStartupProperties@@SAPAV1@XZ @ 9 NONAME ; class CStartupProperties * CStartupProperties::NewL(void)
	?NewLC@CStartupProperties@@SAPAV1@AAVTResourceReader@@@Z @ 10 NONAME ; class CStartupProperties * CStartupProperties::NewLC(class TResourceReader &)
	?NewLC@CStartupProperties@@SAPAV1@ABVTDesC16@@0@Z @ 11 NONAME ; class CStartupProperties * CStartupProperties::NewLC(class TDesC16 const &, class TDesC16 const &)
	?NewLC@CStartupProperties@@SAPAV1@XZ @ 12 NONAME ; class CStartupProperties * CStartupProperties::NewLC(void)
	?NoOfRetries@CStartupProperties@@QBEHXZ @ 13 NONAME ; int CStartupProperties::NoOfRetries(void) const
	?RecoveryMethod@CStartupProperties@@QBE?AW4TRecoveryMethod@@XZ @ 14 NONAME ; enum TRecoveryMethod CStartupProperties::RecoveryMethod(void) const
	?RestartMode@CStartupProperties@@QBEHXZ @ 15 NONAME ; int CStartupProperties::RestartMode(void) const
	?SetFileParamsL@CStartupProperties@@QAEXABVTDesC16@@0@Z @ 16 NONAME ; void CStartupProperties::SetFileParamsL(class TDesC16 const &, class TDesC16 const &)
	?SetMonitored@CStartupProperties@@QAEXH@Z @ 17 NONAME ; void CStartupProperties::SetMonitored(int)
	?SetNoOfRetries@CStartupProperties@@QAEXH@Z @ 18 NONAME ; void CStartupProperties::SetNoOfRetries(int)
	?SetRecoveryParams@CStartupProperties@@QAEXW4TRecoveryMethod@@H@Z @ 19 NONAME ; void CStartupProperties::SetRecoveryParams(enum TRecoveryMethod, int)
	?SetStartInBackground@CStartupProperties@@QAEXH@Z @ 20 NONAME ; void CStartupProperties::SetStartInBackground(int)
	?SetStartMethod@CStartupProperties@@QAEXW4TStartMethod@@@Z @ 21 NONAME ; void CStartupProperties::SetStartMethod(enum TStartMethod)
	?SetStartupType@CStartupProperties@@QAEXW4TStartupType@@@Z @ 22 NONAME ; void CStartupProperties::SetStartupType(enum TStartupType)
	?SetTimeout@CStartupProperties@@QAEXH@Z @ 23 NONAME ; void CStartupProperties::SetTimeout(int)
	?SetViewless@CStartupProperties@@QAEXH@Z @ 24 NONAME ; void CStartupProperties::SetViewless(int)
	?Size@CStartupProperties@@QBEHXZ @ 25 NONAME ; int CStartupProperties::Size(void) const
	?StartInBackground@CStartupProperties@@QBEHXZ @ 26 NONAME ; int CStartupProperties::StartInBackground(void) const
	?StartMethod@CStartupProperties@@QBE?AW4TStartMethod@@XZ @ 27 NONAME ; enum TStartMethod CStartupProperties::StartMethod(void) const
	?StartupType@CStartupProperties@@QBE?AW4TStartupType@@XZ @ 28 NONAME ; enum TStartupType CStartupProperties::StartupType(void) const
	?Timeout@CStartupProperties@@QBEHXZ @ 29 NONAME ; int CStartupProperties::Timeout(void) const
	?Version@CStartupProperties@@QBEHXZ @ 30 NONAME ; int CStartupProperties::Version(void) const
	?Viewless@CStartupProperties@@QBEHXZ @ 31 NONAME ; int CStartupProperties::Viewless(void) const
	?ActionOnCommandFailure@CStartupProperties@@QBE?AW4TActionOnCommandFailure@@XZ @ 32 NONAME ; enum TActionOnCommandFailure CStartupProperties::ActionOnCommandFailure(void) const
	?SetActionOnCommandFailure@CStartupProperties@@QAEXW4TActionOnCommandFailure@@@Z @ 33 NONAME ; void CStartupProperties::SetActionOnCommandFailure(enum TActionOnCommandFailure)
	?Reset@CStartupProperties@@QAEXXZ @ 34 NONAME ; void CStartupProperties::Reset(void)

